This archive contains
(i) Jupyter notebooks with examples of how to use [STACIE](https://github.com/molmod/stacie).
(ii) The output files needed to execute the example notebooks.
Detailed descriptions and input files with which trajectories can be reproduced
are provided in STACIE's Git repository: <https://github.com/molmod/stacie/>.
Instructions for running the examples can be found in the `README.pdf` file included in this archive.

All files in this dataset are distributed under a choice of license:
either the Creative Commons Attribution-ShareAlike 4.0 International license (CC BY-SA 4.0)
or the GNU Lesser General Public License, version 3 or later (LGPL-v3+).
The SPDX License Expression for the documentation is `CC-BY-SA-4.0 OR LGPL-3.0-or-later`.

You should have received a copy of the CC BY-SA 4.0 and LGPL-v3+ licenses along with the data set.
If not, see:

- <https://creativecommons.org/licenses/by-sa/4.0/>
- <https://www.gnu.org/licenses/>
